/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

package gov.anl.aps.dm.portal.controllers;

import gov.anl.aps.dm.portal.model.beans.RoleTypeFacade;
import gov.anl.aps.dm.portal.model.beans.UserInfoFacade;
import gov.anl.aps.dm.portal.model.entities.RoleType;
import gov.anl.aps.dm.portal.model.entities.UserInfo;
import gov.anl.aps.dm.portal.utilities.SessionUtility;
import java.io.Serializable;
import java.util.List;
import javax.ejb.EJB;
import javax.enterprise.context.SessionScoped;
import javax.inject.Named;
import org.apache.log4j.Logger;

@Named("userSystemRoleController")
@SessionScoped
public class UserSystemRoleController  implements Serializable
{
 
    @EJB
    private UserInfoFacade userInfoFacade;

    @EJB
    private RoleTypeFacade roleTypeFacade;

    public UserSystemRoleController() {
        this.systemRoleTable = new SystemRoleTypeTable();
        this.noSystemRoleTable = new NoSystemRoleTypeTable();
    }

    class SystemRoleTypeTable extends DataTableController<UserInfo> {

        @Override
        public String getClassName() {
            return "UserInfo";
        }

        @Override
        public List<UserInfo> findAll() {
            try {
                int id = Integer.parseInt(systemRoleId);
                return userInfoFacade.findSystemRoleUsers(id);
            } catch (NumberFormatException e) {
                return null;
            }
        }
    }
    
    class NoSystemRoleTypeTable extends DataTableController<UserInfo> {

        @Override
        public String getClassName() {
            return "UserInfo";
        }

        @Override
        public List<UserInfo> findAll() {
            try {
                int id = Integer.parseInt(systemRoleId);
                return userInfoFacade.findNoSystemRoleUsers(id);
            } catch (NumberFormatException e) {
                return null;
            }
        }
    }
    
    private SystemRoleTypeTable systemRoleTable;
    private NoSystemRoleTypeTable noSystemRoleTable;

    private String systemRoleId;

    private static final Logger logger = Logger.getLogger(UserSystemRoleController.class.getName());

    public SystemRoleTypeTable getSystemRoleTable() {
        return systemRoleTable;
    }

    public void setSystemRoleTable(SystemRoleTypeTable systemRoleTable) {
        this.systemRoleTable = systemRoleTable;
    }

     public NoSystemRoleTypeTable getNoSystemRoleTable() {
        return noSystemRoleTable;
    }

    public void setNoSystemRoleTable(NoSystemRoleTypeTable noSystemRoleTable) {
        this.noSystemRoleTable = noSystemRoleTable;
    }

     public String getSystemRoleId() {
        return systemRoleId;
    }

    public void setSystemRoleId(String systemRoleId) {
        this.systemRoleId = systemRoleId;
    }
         
    public String getSystemRoleName() {
        int id = Integer.parseInt(systemRoleId);
        return roleTypeFacade.findById(id).getName(); 
    }

     public String resetSystemRoleUserList() {
        logger.debug("Resetting System Role User list");
        systemRoleTable.resetList();
        return "/views/userSystemRole/list?faces-redirect=true";
    }
    
     public void resetNoSystemRoleUserList() {
        logger.debug("Resetting System Role Add User list");
        noSystemRoleTable.resetList();
    }
    
   public String displayRole(String user) {
       // for now this method returns "Administrator" if user has this role, and "User" otherwise
        RoleType rt = roleTypeFacade.findById(1);
        if (rt == null) {
            return null;
        }
        if (rt.isAdmin(user)) {
            return "Administrator";
        }
        else {
            return "User";            
        }           
    }

    public String prepareSystemRoleView() {
        logger.debug("Preparing system role view");
        noSystemRoleTable.resetList();
        return resetSystemRoleUserList();
    }

    public String addSystemRole() {
        int id = Integer.parseInt(systemRoleId);
        RoleType rt = roleTypeFacade.findById(id);
        if (rt != null) {
            List<UserInfo> uiList = noSystemRoleTable.getSelectedObjectList();

            if (uiList == null) {
                logger.debug("null selected list");
            } else if (uiList.isEmpty()) {
                logger.debug("empty selected list");
            } else {
                for (UserInfo userInfo : uiList) {
                    rt.addRoleTypeToUser(userInfo);
                }
            }
        }
        try {
            roleTypeFacade.edit(rt);
            resetNoSystemRoleUserList();
            return resetSystemRoleUserList();
        } catch (RuntimeException ex) {
            SessionUtility.addErrorMessage("Error", "Could not update RoleType" + ": " + ex.getMessage());
            return null;
        }
    }

    public String removeSystemRole() {
        logger.debug("removing system role from user");
        int id = Integer.parseInt(systemRoleId);
        RoleType rt = roleTypeFacade.findById(id);
        if (rt != null) {
            rt.removeRoleTypeFromUser(systemRoleTable.currentObject);
        }
        try {
        roleTypeFacade.edit(rt);
        resetNoSystemRoleUserList();
        return resetSystemRoleUserList();
        }
        catch (RuntimeException ex) {
            SessionUtility.addErrorMessage("Error", "Could not update RoleType" + ": " + ex.getMessage());
            return null;
        }        
     }

}
